<?php

namespace Project\Pm\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Project\Pm\Interfaces\ProjectRepositoryInterface;

class ProjectPublicController extends BaseController
{
    // use ProjectWorkflow;

    /**
     * Constructor.
     *
     * @param type \Project\Project\Interfaces\ProjectRepositoryInterface $project
     *
     * @return type
     */
    public function __construct(ProjectRepositoryInterface $project)
    {
        $this->repository = $project;
        parent::__construct();
    }

    /**
     * Show project's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $projects = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->setMetaTitle(trans('pm::project.names'))
            ->view('pm::public.project.index')
            ->data(compact('projects'))
            ->output();
    }


    /**
     * Show project.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $project = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->setMetaTitle($project->name . trans('pm::project.name'))
            ->view('pm::public.project.show')
            ->data(compact('project'))
            ->output();
    }

}
