<?php

namespace Project\Pm\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Project\Pm\Http\Requests\RoadmapRequest;
use Project\Pm\Interfaces\RoadmapRepositoryInterface;
use Project\Pm\Models\Roadmap;
use Project\Pm\Forms\Roadmap as Form;

/**
 * APIController  class for roadmap.
 */
class RoadmapAPIController extends BaseController
{

    /**
     * Initialize roadmap resource controller.
     *
     * @param type RoadmapRepositoryInterface $roadmap
     *
     * @return null
     */
    public function __construct(RoadmapRepositoryInterface $roadmap)
    {
        parent::__construct();
        $this->repository = $roadmap;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Project\Pm\Repositories\Criteria\RoadmapResourceCriteria::class);
    }

    /**
     * Display a list of roadmap.
     *
     * @return Response
     */
    public function index(RoadmapRequest $request)
    {
        return $this->repository
            ->setPresenter(\Project\Pm\Repositories\Presenter\RoadmapPresenter::class)
            ->paginate();
    }

    /**
     * Display roadmap.
     *
     * @param Request $request
     * @param Model   $roadmap
     *
     * @return Response
     */
    public function show(RoadmapRequest $request, Roadmap $roadmap)
    {
        return $roadmap->setPresenter(\Project\Pm\Repositories\Presenter\RoadmapListPresenter::class);
        ;
    }

    /**
     * Create new roadmap.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(RoadmapRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('pm::roadmap.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('pm/roadmap/' . $roadmap->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('pm/roadmap');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the roadmap.
     *
     * @param Request $request
     * @param Model   $roadmap
     *
     * @return Response
     */
    public function update(RoadmapRequest $request, Roadmap $roadmap)
    {
        try {
            $data = $request->all();

            $roadmap->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('pm::roadmap.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('pm/roadmap/' . $roadmap->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('pm/roadmap/' . $roadmap->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the roadmap.
     *
     * @param Model   $roadmap
     *
     * @return Response
     */
    public function destroy(RoadmapRequest $request, Roadmap $roadmap)
    {
        try {
            $roadmap->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('pm::roadmap.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('pm/roadmap/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('pm/roadmap/' . $roadmap->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
