<?php

namespace Project\Pm\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Project\Pm\Interfaces\RoadmapRepositoryInterface;

class RoadmapPublicController extends BaseController
{
    // use RoadmapWorkflow;

    /**
     * Constructor.
     *
     * @param type \Project\Roadmap\Interfaces\RoadmapRepositoryInterface $roadmap
     *
     * @return type
     */
    public function __construct(RoadmapRepositoryInterface $roadmap)
    {
        $this->repository = $roadmap;
        parent::__construct();
    }

    /**
     * Show roadmap's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $roadmaps = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->setMetaTitle(trans('pm::roadmap.names'))
            ->view('pm::public.roadmap.index')
            ->data(compact('roadmaps'))
            ->output();
    }


    /**
     * Show roadmap.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $roadmap = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->setMetaTitle($roadmap->name . trans('pm::roadmap.name'))
            ->view('pm::public.roadmap.show')
            ->data(compact('roadmap'))
            ->output();
    }

}
