<?php

namespace Project\Pm\Policies;

use Litepie\User\Contracts\UserPolicy;
use Project\Pm\Models\Roadmap;

class RoadmapPolicy
{

    /**
     * Determine if the given user can view the roadmap.
     *
     * @param UserPolicy $user
     * @param Roadmap $roadmap
     *
     * @return bool
     */
    public function view(UserPolicy $user, Roadmap $roadmap)
    {
        if ($user->canDo('pm.roadmap.view') && $user->isAdmin()) {
            return true;
        }

        return $roadmap->user_id == user_id() && $roadmap->user_type == user_type();
    }

    /**
     * Determine if the given user can create a roadmap.
     *
     * @param UserPolicy $user
     * @param Roadmap $roadmap
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('pm.roadmap.create');
    }

    /**
     * Determine if the given user can update the given roadmap.
     *
     * @param UserPolicy $user
     * @param Roadmap $roadmap
     *
     * @return bool
     */
    public function update(UserPolicy $user, Roadmap $roadmap)
    {
        if ($user->canDo('pm.roadmap.edit') && $user->isAdmin()) {
            return true;
        }

        return $roadmap->user_id == user_id() && $roadmap->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given roadmap.
     *
     * @param UserPolicy $user
     * @param Roadmap $roadmap
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Roadmap $roadmap)
    {
        return $roadmap->user_id == user_id() && $roadmap->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given roadmap.
     *
     * @param UserPolicy $user
     * @param Roadmap $roadmap
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Roadmap $roadmap)
    {
        if ($user->canDo('pm.roadmap.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given roadmap.
     *
     * @param UserPolicy $user
     * @param Roadmap $roadmap
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Roadmap $roadmap)
    {
        if ($user->canDo('pm.roadmap.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
