<?php

namespace Project\Pm\Policies;

use Litepie\User\Contracts\UserPolicy;
use Project\Pm\Models\Sprint;

class SprintPolicy
{

    /**
     * Determine if the given user can view the sprint.
     *
     * @param UserPolicy $user
     * @param Sprint $sprint
     *
     * @return bool
     */
    public function view(UserPolicy $user, Sprint $sprint)
    {
        if ($user->canDo('pm.sprint.view') && $user->isAdmin()) {
            return true;
        }

        return $sprint->user_id == user_id() && $sprint->user_type == user_type();
    }

    /**
     * Determine if the given user can create a sprint.
     *
     * @param UserPolicy $user
     * @param Sprint $sprint
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('pm.sprint.create');
    }

    /**
     * Determine if the given user can update the given sprint.
     *
     * @param UserPolicy $user
     * @param Sprint $sprint
     *
     * @return bool
     */
    public function update(UserPolicy $user, Sprint $sprint)
    {
        if ($user->canDo('pm.sprint.edit') && $user->isAdmin()) {
            return true;
        }

        return $sprint->user_id == user_id() && $sprint->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given sprint.
     *
     * @param UserPolicy $user
     * @param Sprint $sprint
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Sprint $sprint)
    {
        return $sprint->user_id == user_id() && $sprint->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given sprint.
     *
     * @param UserPolicy $user
     * @param Sprint $sprint
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Sprint $sprint)
    {
        if ($user->canDo('pm.sprint.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given sprint.
     *
     * @param UserPolicy $user
     * @param Sprint $sprint
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Sprint $sprint)
    {
        if ($user->canDo('pm.sprint.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
