<?php

namespace Project\Pm\Policies;

use Litepie\User\Contracts\UserPolicy;
use Project\Pm\Models\Worklog;

class WorklogPolicy
{

    /**
     * Determine if the given user can view the worklog.
     *
     * @param UserPolicy $user
     * @param Worklog $worklog
     *
     * @return bool
     */
    public function view(UserPolicy $user, Worklog $worklog)
    {
        if ($user->canDo('pm.worklog.view') && $user->isAdmin()) {
            return true;
        }

        return $worklog->user_id == user_id() && $worklog->user_type == user_type();
    }

    /**
     * Determine if the given user can create a worklog.
     *
     * @param UserPolicy $user
     * @param Worklog $worklog
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('pm.worklog.create');
    }

    /**
     * Determine if the given user can update the given worklog.
     *
     * @param UserPolicy $user
     * @param Worklog $worklog
     *
     * @return bool
     */
    public function update(UserPolicy $user, Worklog $worklog)
    {
        if ($user->canDo('pm.worklog.edit') && $user->isAdmin()) {
            return true;
        }

        return $worklog->user_id == user_id() && $worklog->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given worklog.
     *
     * @param UserPolicy $user
     * @param Worklog $worklog
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Worklog $worklog)
    {
        return $worklog->user_id == user_id() && $worklog->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given worklog.
     *
     * @param UserPolicy $user
     * @param Worklog $worklog
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Worklog $worklog)
    {
        if ($user->canDo('pm.worklog.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given worklog.
     *
     * @param UserPolicy $user
     * @param Worklog $worklog
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Worklog $worklog)
    {
        if ($user->canDo('pm.worklog.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
