<?php

namespace Project\Pm\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Project\Pm\Models\Pm;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Project\Pm\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/pm/comment/*')) {
            Route::bind('comment', function ($comment) {
                $commentrepo = $this->app->make('Project\Pm\Interfaces\CommentRepositoryInterface');
                return $commentrepo->findorNew($comment);
            });
        }

        if (Request::is('*/pm/page/*')) {
            Route::bind('page', function ($page) {
                $pagerepo = $this->app->make('Project\Pm\Interfaces\PageRepositoryInterface');
                return $pagerepo->findorNew($page);
            });
        }

        if (Request::is('*/pm/project/*')) {
            Route::bind('project', function ($project) {
                $projectrepo = $this->app->make('Project\Pm\Interfaces\ProjectRepositoryInterface');
                return $projectrepo->findorNew($project);
            });
        }

        if (Request::is('*/pm/roadmap/*')) {
            Route::bind('roadmap', function ($roadmap) {
                $roadmaprepo = $this->app->make('Project\Pm\Interfaces\RoadmapRepositoryInterface');
                return $roadmaprepo->findorNew($roadmap);
            });
        }

        if (Request::is('*/pm/sprint/*')) {
            Route::bind('sprint', function ($sprint) {
                $sprintrepo = $this->app->make('Project\Pm\Interfaces\SprintRepositoryInterface');
                return $sprintrepo->findorNew($sprint);
            });
        }

        if (Request::is('*/pm/worklog/*')) {
            Route::bind('worklog', function ($worklog) {
                $worklogrepo = $this->app->make('Project\Pm\Interfaces\WorklogRepositoryInterface');
                return $worklogrepo->findorNew($worklog);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {   
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

}
